/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils;

import java.awt.Color;

public class MutableColor {

	private int m_red;
	private int m_green;
	private int m_blue;

	public int getRed() {
		return m_red;
	}

	public void setRed(int red) {
		m_red = red;
	}

	public int getGreen() {
		return m_green;
	}

	public void setGreen(int green) {
		m_green = green;
	}

	public int getBlue() {
		return m_blue;
	}

	public void setBlue(int blue) {
		m_blue = blue;
	}

	public void setRGB(int red, int green, int blue) {
		m_red = red;
		m_green = green;
		m_blue = blue;
	}

	public void setColor(int rgb) {
		m_red = (rgb >> 16) & 0xFF;
		m_green = (rgb >> 8) & 0xFF;
		m_blue = (rgb >> 0) & 0xFF;
	}

	public int rgb() {
		return ((m_red & 0xFF) << 16) | ((m_green & 0xFF) << 8) | ((m_blue & 0xFF) << 0);
	}

	public Color getColor() {
		return new Color(rgb());
	}

	public MutableColor() {
	}

	public MutableColor(int red, int green, int blue) {
		setRGB(red, green, blue);
	}

	public MutableColor(int rgb) {
		setColor(rgb);
	}

	public Object clone() {
		return new MutableColor(m_red, m_green, m_blue);
	}

	public int hashCode() {
		return m_red ^ m_green ^ m_blue;
	}

	public boolean equals(Object other) {
		MutableColor o = (MutableColor) other;
		return getRed() == o.getRed() && getGreen() == o.getGreen() && getBlue() == o.getBlue();
	}

	public void invert() {
		m_red = 255 - m_red;
		m_green = 255 - m_green;
		m_blue = 255 - m_blue;
	}

	public MutableColor add(int red, int green, int blue) {
		m_red += red;
		m_green += green;
		m_blue += blue;
		normalize();

		return this;
	}

	public MutableColor add(int rgb) {
		setColor(rgb() + rgb);
		return this;
	}

	public void normalize() {
		m_red = Math.max(0, Math.min(m_red, 255));
		m_green = Math.max(0, Math.min(m_green, 255));
		m_blue = Math.max(0, Math.min(m_blue, 255));
	}

}
