/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.collections;

import java.lang.reflect.Array;
import java.util.Collection;
import java.util.LinkedList;

public class Functional {

	public static interface MapFunction<Inp, Out> {
		public Out map(Inp i);
	}

	public static interface Predicate<T> {
		public boolean get(T t);
	}

	public static interface Visitor<T> {
		public void visit(T t);
	}

	public static <T> void iterate(Iterable<? extends T> it, Visitor<T> v) {
		for (T t : it) {
			v.visit(t);
		}
	}

	public static <Inp, Out, CollType extends Collection<Out>> CollType map(Iterable<Inp> input, CollType out, MapFunction<Inp, Out> mf) {
		if (input != null) {
			for (Inp i : input) {
				out.add(mf.map(i));
			}
		}
		return out;
	}

	public static <Inp, Out> Collection<Out> map(Iterable<Inp> input, MapFunction<Inp, Out> mf) {
		return map(input, new LinkedList<Out>(), mf);
	}

	public static <Inp, Out, CollType extends Collection<Out>> CollType map(Inp[] input, CollType out, MapFunction<Inp, Out> mf) {
		if (input != null) {
			for (Inp i : input) {
				out.add(mf.map(i));
			}
		}
		return out;
	}

	@SuppressWarnings("unchecked")
	public static <Inp, Out> Out[] map(Inp[] input, Class<Out> outCls, MapFunction<Inp, Out> mf) {
		Out[] o = (Out[]) Array.newInstance(outCls, input.length);
		for (int i = 0; i < o.length; i++) {
			o[i] = mf.map(input[i]);
		}
		return o;
	}

	public static <T, CollType extends Collection<T>> CollType filter(Collection<T> input, CollType output, Predicate<T> p) {
		for (T i : input) {
			if (p.get(i)) {
				output.add(i);
			}
		}
		return output;
	}

}
