/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.collections;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

public class VHashMap<K, V> extends HashMap<K, V> {
	private static final long serialVersionUID = 1L;

	public static interface LazyCreator<K, V> {
		public V create(K k);
	}

	public static interface Modifier<From, To> {
		public To modify(From k);
	}

	public static interface MapEnumerator<K, V> {
		public void visit(int idx, K key, V value);
	}

	protected LazyCreator<K, V> creator;

	public VHashMap() {
		// TODO Auto-generated constructor stub
	}

	public VHashMap(LazyCreator<K, V> creator) {
		this.creator = creator;
	}

	public VHashMap(K key, V val) {
		of(key, val);
	}

	public <OtherKey> VHashMap<K, V> addAllWithKeyModifier(Map<OtherKey, V> other, Modifier<OtherKey, K> km) {
		for (Entry<OtherKey, V> e : other.entrySet()) {
			put(km.modify(e.getKey()), e.getValue());
		}
		return this;
	}

	public <OtherValue> VHashMap<K, V> addAllWithValueModifier(Map<K, OtherValue> other, Modifier<OtherValue, V> vm) {
		for (Entry<K, OtherValue> e : other.entrySet()) {
			put(e.getKey(), vm.modify(e.getValue()));
		}
		return this;
	}

	public <OtherKey, OtherValue> VHashMap<K, V> addAllWithModifiers(Map<OtherKey, OtherValue> other, Modifier<OtherKey, K> km, Modifier<OtherValue, V> vm) {
		for (Entry<OtherKey, OtherValue> e : other.entrySet()) {
			put(km.modify(e.getKey()), vm.modify(e.getValue()));
		}
		return this;
	}

	public void setCreator(LazyCreator<K, V> creator) {
		this.creator = creator;
	}

	public VHashMap<K, V> of(K key, V val) {
		put(key, val);
		return this;
	}

	public V getLazy(K k) {
		V v = get(k);
		if (v == null && creator != null) {
			put(k, v = creator.create(k));
		}
		return v;
	}

	public void enumerate(MapEnumerator<K, V> enumerator) {
		int idx = 0;
		for (Entry<K, V> e : entrySet()) {
			enumerator.visit(idx++, e.getKey(), e.getValue());
		}
	}
}
