/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.http;

import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Map.Entry;

public class HttpGet extends HttpRequest {

	public HttpGet(String url) throws MalformedURLException {
		super(url);
	}

	@Override
	public HttpResponse send() throws IOException {
		URL url = new URL(this.url + "?" + appendParams());

		HttpURLConnection conn = (HttpURLConnection) url.openConnection();
		conn.setDoOutput(true);
		conn.setUseCaches(false);
		conn.setRequestMethod("GET");

		for (Entry<String, String> e : headers.entrySet()) {
			conn.setRequestProperty(e.getKey(), e.getValue());
		}
		return new HttpResponse(conn.getResponseCode(), conn.getInputStream());
	}

	private StringBuilder appendParams() {
		StringBuilder dataBuilder = new StringBuilder();
		for (Entry<String, String> e : params.entrySet()) {
			dataBuilder.append(e.getKey()).append("=");
			if (e.getValue() != null) {
				dataBuilder.append(e.getValue());
			}
			dataBuilder.append("&");
		}
		return dataBuilder.deleteCharAt(dataBuilder.length() - 1);
	}

}
