/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.http;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public abstract class HttpRequest {

	protected String url;
	protected Headers headers = new Headers();
	protected Map<String, String> params = new HashMap<String, String>();

	protected HttpRequest(String url) {
		this.url = url;
	}

	public abstract HttpResponse send() throws IOException;

	public HttpRequest withHeader(String key, String value) {
		headers.put(key, value);
		return this;
	}

	public HttpRequest withHeaders(Headers headers) {
		this.headers.putAll(headers);
		return this;
	}

	public <T> HttpRequest withParameter(String key, T value) {
		params.put(key, value.toString());
		return this;
	}

	public HttpRequest withParameters(Map<String, String> params) {
		this.params.putAll(params);
		return this;
	}

}
