/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.io;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public class FileUtils {

	public static void copy(File src, File dst, int bufferSize) {
		if (!dst.getParentFile().exists()) {
			dst.getParentFile().mkdirs();
		}
		InputStream is = null;
		OutputStream os = null;

		try {
			is = new FileInputStream(src);
			os = new FileOutputStream(dst);

			byte[] b = new byte[bufferSize];
			int l = 0;

			while ((l = is.read(b)) > 0) {
				os.write(b, 0, l);
			}

		}
		catch (Exception e) {
			System.err.println("Error occured while copying " + src + " to " + dst);
		}
		finally {
			if (is != null) {
				try {
					is.close();
				}
				catch (IOException e) {
				}
			}
			if (os != null) {
				try {
					os.close();
				}
				catch (IOException e) {
				}
			}
		}
	}

	public static void copy(File src, File dst) {
		copy(src, dst, 1024);
	}

}
