/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.jdbc;

import java.util.LinkedList;
import java.util.List;

public class CreateTableStatement {

	public static enum Operation {
		ON_DELETE("ON DELETE"), ON_UPDATE("ON UPDATE");
		private String msg;

		private Operation(String msg) {
			this.msg = msg;
		}

		public String toString() {
			return this.msg;
		}
	}

	public static enum Policy {
		CASCADE, NONE
	}

	private static final String CREATE_TABLE_IF_NOT_EXISTS = "CREATE TABLE IF NOT EXISTS";
	private static final String SPACE = " ";
	private static final String COMMA = ", ";

	private String tableName;
	private List<String> params;

	public CreateTableStatement(String tableName) {
		this.tableName = tableName;
		params = new LinkedList<String>();
	}

	public CreateTableStatement addStatement(String c) {
		params.add(c);
		return this;
	}

	public CreateTableStatement addColumn(String name, String stm) {
		return addStatement(name + " " + stm);
	}

	public CreateTableStatement addPrimaryKey(String name) {
		return addStatement("PRIMARY KEY (" + name + ")");
	}

	public CreateTableStatement addConstraint(String stm) {
		return addStatement("CONSTRAINT " + stm);
	}

	public CreateTableStatement addForeignKey(String col, String fTable, String fCol) {
		return addStatement("FOREIGN KEY (" + col + ") REFERENCES " + fTable + " (" + fCol + ")");
	}

	// @formatter:off
	public CreateTableStatement addForeignKey(
			String col, 
			String fTable, 
			String fCol, 
			CreateTableStatement.Operation op, 
			CreateTableStatement.Policy pol
	) {
		return addStatement(
				"FOREIGN KEY (" + col + ") REFERENCES " + fTable + " (" + fCol + ") " + op + " " + pol);
	}
	// @formatter:on

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append(CREATE_TABLE_IF_NOT_EXISTS).append(SPACE).append(tableName).append(SPACE).append("(");
		for (String c : params) {
			sb.append(c).append(COMMA);
		}
		sb.delete(sb.length() - 2, sb.length());
		sb.append(");");

		return sb.toString();
	}

}
