/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.jdbc;

public class InsertStatement {

	private String[] columns;
	private String[] values;
	private String tableName;

	public InsertStatement() {
		//
	}

	public InsertStatement(String tableName) {
		this.tableName = tableName;
	}

	public InsertStatement withTableName(String tableName) {
		this.tableName = tableName;
		return this;
	}

	public InsertStatement withColumns(String... columns) {
		this.columns = columns;
		return this;
	}

	public InsertStatement withValues(String... values) {
		this.values = values;
		return this;
	}

	@Override
	public String toString() {
		StringBuilder query = new StringBuilder("insert into ").append(tableName);
		if (columns != null) {
			query.append("(");
			for (String col : columns) {
				query.append(col).append(", ");
			}
			query.replace(query.length() - 2, query.length() - 1, ")");
		}

		if (values != null) {
			query.append(" values (");
			for (String val : values) {
				query.append(val).append(", ");
			}
			query.replace(query.length() - 2, query.length() - 1, ")");
		}

		return query.toString();
	}

}
