/*
Copyright 2012  Vesko Georgiev vesko.m.georgiev@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either 
version 3 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.veskogeorgiev.utils.jdbc;

public class UpdateStatement {

	private String[] columns;
	private String[] values;
	private String tableName;
	private String condition;

	public UpdateStatement() {
		//
	}

	public UpdateStatement(String tableName) {
		this.tableName = tableName;
	}

	public UpdateStatement withTableName(String tableName) {
		this.tableName = tableName;
		return this;
	}

	public UpdateStatement withColumns(String... columns) {
		this.columns = columns;
		return this;
	}

	public UpdateStatement withValues(String... values) {
		this.values = values;
		return this;
	}

	public UpdateStatement withCondition(String condition) {
		this.condition = condition;
		return this;
	}

	@Override
	public String toString() {
		StringBuilder query = new StringBuilder("update ").append(tableName).append(" ( ");
		if (columns != null) {
			for (int i = 0; i < columns.length; i++) {
				query.append(columns[i]).append(" = ").append(values[i]).append(", ");
			}
			query.replace(query.length() - 2, query.length() - 1, ")");
		}

		if (condition != null) {
			query.append(" where ").append(condition);
		}
		return query.toString();
	}
}
